;; Generated package description from consult-denote.el  -*- no-byte-compile: t -*-
(define-package "consult-denote" "0.0.0.0.20240607.111006" "Use Consult in tandem with Denote" '((emacs "28.1") (denote "2.3.0") (consult "1.4")) :commit "b477a6ec64a148c186e7114135873e975b05074f" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/consult-denote")
